@@ -76,7 +76,7 @@ def interceptor(rn_environ, *args, **kwargs):
     fn, environ = rn_environ
     
     ctx = TraceContext()
-    
+
     ctx.host = environ.get('HTTP_HOST', '').split(':')[0]
     ctx.service_name = environ.get('PATH_INFO', '')
     
@@ -271,6 +271,9 @@ def inter_tx_trace_auto_on(ctx):
     
     
 def transfer(ctx, headers):
+    if not ctx.mtid:
+        inter_tx_trace_auto_on(ctx)
+        
     if ctx.mtid:
         headers[conf._trace_mtrace_caller_key]=ctx.transfer()
         ctx.mcallee=TraceContextManager.getId()
